@@ -15,7 +15,7 @@ Example:
     >>> from satctl.model import SearchParams
     >>> from datetime import datetime
     >>>
-    >>> source = create_source("s2l2a")
+    >>> source = create_source("s2-l2a")
     >>> params = SearchParams(
     ...     area=my_polygon,
     ...     start=datetime(2023, 1, 1),
@@ -28,6 +28,8 @@ Example:
 import os
 from importlib.resources import files
 
+from satctl.sources import create_source
+
 # override the satpy config path, adding our own custom yaml configs
 # it is non-destructive, i.e. if the variable is already set, we append
 satpy_config_path = os.getenv("SATPY_CONFIG_PATH", None)
@@ -37,3 +39,5 @@ if satpy_config_path is None:
 else:
     satpy_config_path = str([satpy_config_path, local_config_path])
 os.environ["SATPY_CONFIG_PATH"] = satpy_config_path
+
+__all__ = ["create_source"]
