@@ -276,8 +276,7 @@ class EarthDataSource(DataSource):
             list[Granule]: List of granules for this combination
         """
         # Ensure authentication before searching (earthaccess requires global auth)
-        self.authenticator().ensure_authenticated()
-
+        self.authenticator.ensure_authenticated()
         search_kwargs: dict[str, Any] = {
             "short_name": short_name,
             "temporal": (params.start.isoformat(), params.end.isoformat()),
@@ -534,7 +533,13 @@ class EarthDataSource(DataSource):
         scene = self.load_scene(item, datasets=list(datasets_dict.values()))
 
         # Define area using base class helper
-        area_def = self._create_area_from_params(params, scene)
+        area_def = self.define_area(
+            target_crs=params.target_crs_obj,
+            area=params.area_geometry,
+            scene=scene,
+            source_crs=params.source_crs_obj,
+            resolution=params.resolution,
+        )
         scene = self.resample(scene, area_def=area_def)
 
         # Write datasets using base class helper
