@@ -13,6 +13,7 @@ from pydantic import BaseModel
 from satpy.scene import Scene
 
 from satctl.auth import AuthBuilder
+from satctl.auth.eumetsat import EUMETSATAuthenticator
 from satctl.downloaders import DownloadBuilder, Downloader
 from satctl.model import ConversionParams, Granule, ProductInfo, SearchParams
 from satctl.sources import DataSource
@@ -95,7 +96,7 @@ class MTGSource(DataSource):
         groups = match.groups()
         acquisition_time = datetime.strptime(groups[3], "%Y%m%dT%H%M%S").replace(tzinfo=timezone.utc)
         return ProductInfo(
-            instrument="olci",
+            instrument="fci",
             level=groups[1],
             product_type=groups[2],
             acquisition_time=acquisition_time,
@@ -112,8 +113,7 @@ class MTGSource(DataSource):
         """
         # Ensure authentication before searching
         log.debug("Setting up the DataStore client")
-        self.authenticator().ensure_authenticated()
-        catalogue = DataStore(self.authenticator().auth_session)
+        catalogue = DataStore(cast(EUMETSATAuthenticator, self.authenticator).auth_token)
 
         log.debug("Searching catalog")
         collections = [catalogue.get_collection(c) for c in self.collections]
@@ -154,8 +154,7 @@ class MTGSource(DataSource):
         """
         # Ensure authentication before accessing DataStore
         log.debug("Fetching MTG granule by ID: %s", item_id)
-        self.authenticator().ensure_authenticated()
-        catalogue = DataStore(self.authenticator().auth_session)
+        catalogue = DataStore(cast(EUMETSATAuthenticator, self.authenticator).auth_token)
 
         try:
             product = catalogue.get_product(self.collections[0], item_id)
@@ -306,7 +305,13 @@ class MTGSource(DataSource):
             scene = self.load_scene(item, datasets=list(datasets_dict.values()))
 
             # Define area using base class helper
-            area_def = self._create_area_from_params(params, scene)
+            area_def = self.define_area(
+                target_crs=params.target_crs_obj,
+                area=params.area_geometry,
+                scene=scene,
+                source_crs=params.source_crs_obj,
+                resolution=params.resolution,
+            )
             scene = scene.compute()
             scene = self.resample(scene, area_def=area_def)
 
